@@ -9,6 +9,8 @@ To report an issue, please use: {}
 import os
 import json
 import logging
+import shlex
+import subprocess  # nosec B404:blacklist import_subprocess
 from functools import wraps
 from getpass import getpass
 from pathlib import Path
@@ -53,31 +55,47 @@ def two_factor_cli_prompt():
     return input("Verification code: ")
 
 
-@exception_to_message(FileNotFoundError, logger)
-def get_passphrase_from_file_or_prompt(passphrase_file: Optional[str]) -> str:
-    if passphrase_file:
-        return Path(passphrase_file).read_text().strip()
+def get_passphrase_from_cmd(passphrase_cmd: str) -> str:
+    try:
+        # B603:subprocess_without_shell_equals_true
+        # Suppress the warning, user can easily execute the same command
+        # directly in the shell.
+        proc = subprocess.run(shlex.split(passphrase_cmd),  # nosec
+                              stdout=subprocess.PIPE,
+                              stderr=subprocess.PIPE,
+                              check=True)
+        return proc.stdout.decode().strip()
+    except subprocess.CalledProcessError as e:
+        raise UserError("Failed to read passphrase from "
+                        f"'{passphrase_cmd}'. "
+                        f"{format(e.stderr.strip())}") from e
+
+
+@exception_to_message(UserError, logger)
+def get_passphrase_from_cmd_or_prompt(passphrase_cmd: Optional[str]) -> str:
+    if passphrase_cmd:
+        return get_passphrase_from_cmd(passphrase_cmd)
     return getpass("Please enter your gpg private key password:")
 
 
 @wraps(workflows_encrypt)
-def encrypt(*args, config: Config, dry_run: bool, passphrase_file: Optional[str],
+def encrypt(*args, config: Config, dry_run: bool, passphrase_cmd: Optional[str],
             **kwargs):
     if config.sign_encrypted_data and not dry_run:
-        kwargs["passphrase"] = get_passphrase_from_file_or_prompt(
-            passphrase_file)
+        kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(
+            passphrase_cmd)
     else:
         kwargs["passphrase"] = None
     return workflows_encrypt(*args, config=config, dry_run=dry_run, **kwargs)
 
 
 @wraps(workflows_decrypt)
-def decrypt(*args, dry_run: bool, passphrase_file: Optional[str], **kwargs):
+def decrypt(*args, dry_run: bool, passphrase_cmd: Optional[str], **kwargs):
     if dry_run:
         kwargs["passphrase"] = None
     else:
-        kwargs["passphrase"] = get_passphrase_from_file_or_prompt(
-            passphrase_file)
+        kwargs["passphrase"] = get_passphrase_from_cmd_or_prompt(
+            passphrase_cmd)
     return workflows_decrypt(*args, dry_run=dry_run, **kwargs)
 
 
@@ -90,6 +108,7 @@ def transfer(files: List[str],
              protocol=None,
              protocol_args: Dict[str, Any] = None,
              dry_run: bool = False,
+             verify: bool = True,
              progress=None):
     if connection is not None:
         if protocol is not None:
@@ -109,6 +128,7 @@ def transfer(files: List[str],
                               config=config,
                               two_factor_callback=two_factor_callback,
                               dry_run=dry_run,
+                              verify=verify,
                               progress=progress)
 
 
@@ -124,9 +144,11 @@ class Cli(Subcommands):
     version = VERSION_WITH_DEPS
     config = load_config_check()
     passphrase_override = dict(help="Instead of asking for passphrase, "
-                                    "read it from a file",
-                               name="passphrase-file",
-                               dest="passphrase_file")
+                                    "get it from an external command "
+                                    "(passphrase must be returned to the "
+                                    "standard output)",
+                               name="passphrase-cmd",
+                               dest="passphrase_cmd")
     logger = logging.getLogger()
     add_rotating_file_handler_to_logger(logger,
                                         log_dir=config.log_dir,
@@ -189,7 +211,8 @@ class Cli(Subcommands):
                                    "to use the protocol and protocol args from the "
                                    "config. The protocol args can be overwritten by "
                                    "the protocol_args option"),
-                "dry_run": dict(help="Use this flag to perform checks on the data only")
+                "dry_run": dict(help="Use this flag to perform checks on the data only"),
+                "verify": dict(help="Verify DTR ID")
             }),
         Subcommand(
             decorate(
