@@ -145,7 +145,7 @@ def extract(archive: IO[bytes], *files):
                     yield (tar.extractfile(file_name) for file_name in files)
 
             except KeyError as e:
-                raise UserError(f"In archive {archive.name}: {e.args[0]}")
+                raise UserError(f"In archive {archive.name}: {e.args[0]}") from e
 
 
 def unpack(archive, dest: str) -> List[str]:
