@@ -30,7 +30,7 @@ def to_user_error(error_types: ExceptionType):
             try:
                 return f(*args, **kwargs)
             except error_types as e:
-                raise UserError(format(e))
+                raise UserError(format(e)) from e
         return wrapped
     return _to_user_error
 
@@ -43,7 +43,7 @@ def to_user_error_gen(error_types: ExceptionType):
             try:
                 yield from f(*args, **kwargs)
             except error_types as e:
-                raise UserError(format(e))
+                raise UserError(format(e)) from e
         return wrapped
     return _to_user_error
 
@@ -100,7 +100,7 @@ def upload_keys(fingerprints: List[str], keyserver: str,
         gpg_store.send_keys(*fingerprints,
                             keyserver=keyserver, url_opener=urlopen)
     except urllib.error.URLError:
-        raise KeyserverError(action="upload", keyserver=keyserver)
+        raise KeyserverError(action="upload", keyserver=keyserver) from None
 
 
 def download_keys(fingerprints: List[str], keyserver: str,
@@ -110,7 +110,7 @@ def download_keys(fingerprints: List[str], keyserver: str,
         gpg_store.recv_keys(*fingerprints,
                             keyserver=keyserver, url_opener=urlopen)
     except urllib.error.URLError:
-        raise KeyserverError(action='download', keyserver=keyserver)
+        raise KeyserverError(action='download', keyserver=keyserver) from None
 
 
 def detach_sign_file(src: Union[bytes, IO[bytes]], signature_fingerprint: str,
@@ -121,7 +121,7 @@ def detach_sign_file(src: Union[bytes, IO[bytes]], signature_fingerprint: str,
                                   signature_fingerprint) as out:
             return out.read()
     except gpg.cmd.GPGError as e:
-        raise UserError(f"File signing failed. {e}")
+        raise UserError(f"File signing failed. {e}") from e
 
 
 def check_password(user_fingerprint: str, passphrase: str,
@@ -131,7 +131,7 @@ def check_password(user_fingerprint: str, passphrase: str,
         with gpg_store.detach_sig(b"test", passphrase, user_fingerprint):
             pass
     except gpg.cmd.GPGError:
-        raise UserError("GPG password is incorrect")
+        raise UserError("GPG password is incorrect") from None
 
 
 class KeyType(enum.Enum):
@@ -154,7 +154,7 @@ def open_gpg_dir(gpg_dir: str) -> GPGStore:
     try:
         return GPGStore(config_dir=gpg_dir)
     except ValueError:
-        raise UserError(f'unable to open GnuPG directory [{gpg_dir}].')
+        raise UserError(f'unable to open GnuPG directory [{gpg_dir}].') from None
 
 
 def retrieve_keys(gpg_store: GPGStore,
@@ -228,7 +228,7 @@ def search_pub_key(search_term: str,
         key, = keys
     except ValueError:
         raise UnpackError(keys, key_type=KeyType.public,
-                          search_value=search_term)
+                          search_value=search_term) from None
     return key
 
 
@@ -242,7 +242,7 @@ def search_priv_key(search_term: str,
         key, = keys
     except ValueError:
         raise UnpackError(keys, key_type=KeyType.secret,
-                          search_value=search_term)
+                          search_value=search_term) from None
     return key
 
 
@@ -311,7 +311,7 @@ def encrypt_and_sign_file(file_object_to_encrypt: IO[bytes],
         except gpg.cmd.GPGError:
             delete_files(output_file)
             raise UserError(f'encryption failed for file [{output_file}]. '
-                            f'Maybe you entered a wrong passphrase.')
+                            f'Maybe you entered a wrong passphrase.') from None
     if not Path(output_file).is_file():
         raise UserError(f'encryption failed for [{output_file}].')
 
@@ -321,7 +321,7 @@ def get_recipient_email(key: gpg.Key) -> str:
         email = key.uids[0].email
     except (IndexError, UnpackError):
         raise UserError(
-            f"Could not determine email address for gpg key {key.key_id}.")
+            f"Could not determine email address for gpg key {key.key_id}.") from None
     return email
 
 
@@ -339,7 +339,7 @@ def decrypt(f: io.FileIO, dest: str, gpg_store: GPGStore,
                 raise UserError("Output file does not exist")
         except gpg.cmd.GPGError as e:
             raise UserError("Failed to decrypt. Error message from gpg:\n" +
-                            format(e))
+                            format(e)) from e
     if not sender_fprs:
         warnings.warn("Encrypted package is not signed by the sender")
     elif len(sender_fprs) > 1:
@@ -399,6 +399,6 @@ def request_key_signature(keyid: str, signing_endpoint: str) -> bool:
         with urlopen(signing_endpoint, data):  # nosec
             return True
     except urllib.error.HTTPError as e:
-        raise UserError(json.loads(e.read())["msg"])
+        raise UserError(json.loads(e.read())["msg"]) from e
     except urllib.error.URLError:
-        raise UserError("Could not connect to the server.")
+        raise UserError("Could not connect to the server.") from None
