@@ -1,6 +1,6 @@
 from functools import partial
 from pathlib import Path
-from typing import Callable, Iterable, List, Optional, Tuple
+from typing import Callable, Iterable, List, Optional
 
 from PySide2 import QtCore, QtWidgets
 from PySide2.QtCore import QItemSelectionModel
@@ -31,6 +31,7 @@ class SelectionButton(QPushButton):
         # but does NOT seem to be always the case on Mac OS X.
         self.repaint()
 
+
 class GuiProgress(QtCore.QObject, ProgressInterface):
     updated = QtCore.Signal(int)
     new_label = QtCore.Signal(str)
@@ -92,7 +93,7 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
         btn_select_files.clicked.connect(self.add_files)
 
         self.btn_clear_selected = SelectionButton('Remove selected',
-            self.file_list_view.selectionModel())
+                                                  self.file_list_view.selectionModel())
         self.btn_clear_selected.clicked.connect(self.clear_selected)
 
         btn_clear_list = QtWidgets.QPushButton('Clear list', self)
@@ -121,7 +122,7 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
         # other (than listview) components about the changes to the files list
         self.file_list_model.layoutChanged.emit()
 
-    def add_files(self) -> List[str]:
+    def add_files(self):
         dialog = QtWidgets.QFileDialog(self)
         dialog.setFileMode(QtWidgets.QFileDialog.ExistingFiles)
         dialog.setDirectory(str(self.path))
@@ -131,7 +132,7 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
         if dialog.exec_() == QtWidgets.QDialog.Accepted:
             self._update_paths(dialog.selectedFiles())
 
-    def add_directory(self) -> Tuple[str]:
+    def add_directory(self):
         directory = (QtWidgets.QFileDialog.getExistingDirectory(
             self, 'Select directory', str(self.path)))
         self._update_paths((directory, ))
@@ -154,6 +155,7 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
 
 class PathInput:
     """Path selection widget with a select button and a show path field."""
+
     def __init__(self, directory=True, path: Optional[Path] = Path.home(),
                  parent=None):
         self.parent = parent
@@ -225,12 +227,14 @@ class TabMixin:
     def add_worker_actions(self, worker: Worker):
         """Attach GUI-updating signals to worker"""
         worker.signals.started.connect(self.progress_bar.show)
-        worker.signals.started.connect(lambda: self.run_panel.setEnabled(False))
+        worker.signals.started.connect(
+            lambda: self.run_panel.setEnabled(False))
         worker.signals.logging.connect(self.console.write)
         worker.signals.error.connect(lambda e: self.console.append(str(e[1])))
         worker.signals.finished.connect(lambda: self.progress_bar.setValue(0))
         worker.signals.finished.connect(self.progress_bar.hide)
-        worker.signals.finished.connect(lambda: self.run_panel.setEnabled(True))
+        worker.signals.finished.connect(
+            lambda: self.run_panel.setEnabled(True))
 
 
 def run_dialog(parent, msg: str, password: bool = True):
