@@ -117,6 +117,13 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
     def create_options_panel(self):
         box = QtWidgets.QGroupBox("Select data transfer options")
 
+        verify = QtWidgets.QCheckBox("Verify DTR ID")
+        verify.setStatusTip("Verify DTR (Data Transfer Request) ID")
+        verify.setChecked(self.app_data.transfer_verify)
+        verify.stateChanged.connect(lambda state:
+            setattr(self.app_data, "transfer_verify",
+                    state == QtCore.Qt.Checked))
+
         connections_selection = QtWidgets.QComboBox(box)
         connections_selection.addItems(list(self.app_data.config.connections))
 
@@ -147,6 +154,7 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
                 box_liquidfiles.setVisible(not box_liquidfiles.isVisible())))
 
         layout = QtWidgets.QVBoxLayout()
+        layout.addWidget(verify)
         layout.addWidget(QtWidgets.QLabel("Predefined connections"))
         layout.addWidget(connections_selection)
         layout.addWidget(QtWidgets.QLabel("Protocol"))
@@ -205,6 +213,7 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
                 self.app_data.transfer_protocol_name],
             config=self.app_data.config,
             dry_run=dry_run,
+            verify=self.app_data.transfer_verify,
             progress=progress,
             on_error=lambda _: None,
             two_factor_callback=second_factor_callback)
@@ -230,4 +239,5 @@ class FieldMapping:
             try:
                 self._mapping[key](val)
             except KeyError:
-                raise ValueError(f"Invalid field `{key}` found in your config file")
+                raise ValueError(f"Invalid field `{key}` found in your "
+                                 "config file") from None
