@@ -58,6 +58,10 @@ class Config:
     default_sender: Optional[str] = None
     gui_quit_confirmation: bool = True
 
+    def __post_init__(self):
+        for url in ('dcc_portal_url', 'repo_url'):
+            setattr(self, url, getattr(self, url).rstrip('/'))
+
     @property
     def dcc_portal_pgpkey_endpoint_url(self) -> str:
         return self.dcc_portal_url + "/backend/pgpkey/"
