@@ -1,7 +1,8 @@
 import io
 import os
 from contextlib import contextmanager
-from typing import List, Iterable, Tuple, Callable, Optional
+from typing import List, Iterable, Tuple, Callable, Optional, Sequence, IO, cast
+from collections.abc import Collection
 from itertools import repeat
 from functools import wraps
 
@@ -58,7 +59,7 @@ def progress_iter(iterable: Iterable,
 
 def progress_iter_with_sub_progress(
         iterable: Iterable,
-        progress: ProgressInterface = None,
+        progress: Optional[ProgressInterface] = None,
         weights: List[float] = None,
         iterable_length: int = None) -> Iterable:
     """Add progress tracking through a ProgressInterface to an iterable object.
@@ -83,14 +84,14 @@ def progress_iter_with_sub_progress(
 def _progress_iter_common(wrapper: Callable,
                           iterable: Iterable,
                           progress: ProgressInterface = None,
-                          weights: List[float] = None,
+                          weights: Optional[Sequence[float]] = None,
                           iterable_length: int = None) -> Iterable:
     """Iterate over all values in the input iterable and apply the specified
     wrapper function to them. The wrapper function must accept arguments that
     have the form (item, (start_position, stop)).
     """
     # Get length of input iterable.
-    if hasattr(iterable, '__len__'):
+    if isinstance(iterable, Collection):
         iterable_length = iterable.__len__()
     elif iterable_length is None:
         raise ValueError('iterable has no length attribute and no value was'
@@ -110,7 +111,7 @@ def _progress_iter_common(wrapper: Callable,
     return map(update_progress, zip(iterable, ranges))
 
 
-def weights_to_ranges(weights: List[float],
+def weights_to_ranges(weights: Sequence[float],
                       start: float = 0.) -> Iterable[Tuple[float, float]]:
     """Splits the range (0.0, 1.0) into a number of sub-ranges equal to the
     number of weights, with the size of each sub-range proportional to the
@@ -155,7 +156,7 @@ def _progress_wrapper_with_sub_progress(progress: ProgressInterface) \
     rescaling of its .update() method in the range of 'item_with_range'.
     """
     def progress_wrapper(item_with_range: Tuple[Iterable, Tuple[float, float]]
-                         ) -> Tuple[Iterable, ProgressInterface]:
+                         ) -> Tuple[Iterable, Optional[ProgressInterface]]:
         """item_with_range: iterable and its completion range
         :return: A tuple consisting of the bare item and a ProgressInterface instance
         """
@@ -209,9 +210,9 @@ def scale_progress(progress: ProgressInterface,
 
 
 @contextmanager
-def subprogress(progress: ProgressInterface,
+def subprogress(progress: Optional[ProgressInterface],
                 step_completion_increase: float,
-                step_label: str = '') -> ProgressInterface:
+                step_label: str = ''):
     """Context manager for running a progress bar or a subset of a progress
     bar (i.e. a "scaled progress".
     Usage example:
@@ -251,7 +252,7 @@ class FileObjectProgress:
     instance
     """
 
-    def __init__(self, f_obj: io.IOBase, progress):
+    def __init__(self, f_obj: IO[bytes], progress):
         self._f = f_obj
         self._update = progress.update
         original_pos = f_obj.tell()
@@ -260,8 +261,8 @@ class FileObjectProgress:
         f_obj.seek(original_pos)
 
         if total_size == 0:
-            def wrap_update(x):
-                return x
+            def wrap_update(f):
+                return f
         else:
             def wrap_update(f):
                 @wraps(f)
@@ -299,49 +300,10 @@ class FileObjectProgress:
         return self.__getattr__('name')
 
 
-def with_progress(f: io.IOBase, progress: Optional[ProgressInterface]) -> io.IOBase:
+def with_progress(f: IO[bytes], progress: Optional[ProgressInterface]) -> IO[bytes]:
     if progress is None:
         return f
-    return FileObjectProgress(f, progress)
-
-
-def progress_file_iter(files: List[str],
-                       mode: str,
-                       progress: ProgressInterface) \
-        -> Iterable[FileObjectProgress]:
-    """Associate, to each input file, a sub-progress object whose contribution
-    to the increase in completion of the input progress object is proportional
-    to the file's size. The output is an iterator of file objects with their
-    associated sub-progress already backed-in.
-    Example: this can be used to track progress when reading through a list
-    of files. Each file that is read will then contribute to the increment in
-    progress proportionally to its size.
-
-    :param files: list of files to which progress should be associated.
-    :param mode: file access mode, e.g. 'rb' or 'r'.
-    :param progress: ProgressInterface to which the
-    :return: file objects with backed-in subprogress.
-    """
-    file_size = [os.path.getsize(f) for f in files]
-    if sum(file_size) == 0:
-        yield from (Opener(f, mode) for f in files)
-        return
-    files_with_progress = progress_iter_with_sub_progress(
-        iterable=files,
-        progress=progress,
-        weights=file_size,
-        iterable_length=len(files))
-    for file, sub_progress in files_with_progress:
-        yield Opener(
-            file,
-            mode=mode,
-            wrapper=with_progress_decorator(sub_progress))
-
-
-def with_progress_decorator(progress):
-    def _wrapper(f):
-        return with_progress(f=f, progress=progress)
-    return _wrapper
+    return cast(IO[bytes], FileObjectProgress(f, progress))
 
 
 class Opener:
@@ -370,3 +332,42 @@ class Opener:
 
     def __exit__(self, *args):
         return self._f.__exit__(*args)
+
+
+def progress_file_iter(files: List[str],
+                       mode: str,
+                       progress: Optional[ProgressInterface]) \
+        -> Iterable[IO[bytes]]:
+    """Associate, to each input file, a sub-progress object whose contribution
+    to the increase in completion of the input progress object is proportional
+    to the file's size. The output is an iterator of file objects with their
+    associated sub-progress already backed-in.
+    Example: this can be used to track progress when reading through a list
+    of files. Each file that is read will then contribute to the increment in
+    progress proportionally to its size.
+
+    :param files: list of files to which progress should be associated.
+    :param mode: file access mode, e.g. 'rb' or 'r'.
+    :param progress: ProgressInterface to which the
+    :return: file objects with backed-in subprogress.
+    """
+    file_size = [float(os.path.getsize(f)) for f in files]
+    if sum(file_size) == 0:
+        yield from (cast(IO[bytes], Opener(f, mode)) for f in files)
+        return
+    files_with_progress = progress_iter_with_sub_progress(
+        iterable=files,
+        progress=progress,
+        weights=file_size,
+        iterable_length=len(files))
+    for file, sub_progress in files_with_progress:
+        yield cast(IO[bytes], Opener(
+            file,
+            mode=mode,
+            wrapper=with_progress_decorator(sub_progress)))
+
+
+def with_progress_decorator(progress):
+    def _wrapper(f):
+        return with_progress(f=f, progress=progress)
+    return _wrapper
