@@ -1,5 +1,7 @@
 import os
 
+from . import workflow
+from ..core.error import UserError
 from ..utils.config import create_config as _create_config, get_config_file
 from ..utils.log import create_logger
 
@@ -7,6 +9,7 @@ from ..utils.log import create_logger
 logger = create_logger(__name__)
 
 
+@workflow(logger, (UserError, FileNotFoundError))
 def create():
     """Creates a new default config file in the users config dir"""
     config_file = get_config_file()
