@@ -61,7 +61,7 @@ def check_arg_value(arg_value: str,
     try:
         arg_type(arg_value)
     except ValueError as e:
-        raise UserError(f"Invalid value for argument '{arg_name}': {e}")
+        raise UserError(f"Invalid value for argument '{arg_name}': {e}") from e
 
 
 # pylint: disable=too-many-statements
@@ -85,29 +85,28 @@ def encrypt(files: List[str],
     if sender is None:
         sender = config.default_sender or config.gpg_store.default_key()
         if sender is None:
-            raise UserError(
-                "Sender not specified but no default sender could be determined")
+            raise UserError("Sender not specified with no default sender.")
 
     if not files:
         raise UserError("Empty file list")
 
     files_to_encrypt = list(search_files_recursively(files))
 
-    with logger.log_task('Input data check'):
+    with logger.log_task("Input data check"):
         check_file_read_permission(files_to_encrypt)
         # Retrieve the lowest common directory of all input files/directories.
         root_dir = os.path.commonpath([Path(x).absolute().parent.as_posix()
                                        for x in files])
-        if not offline and dtr_id is None:
-            raise UserError("DTR (Data Transfer Request) ID is missing. Use offline mode if you "
-                            "don't require DTR ID.")
+        if dtr_id is None and not offline:
+            raise UserError("DTR (Data Transfer Request) ID is missing. Use "
+                            "offline mode if you don't require DTR ID.")
         if output_name:
             check_arg_value(Path(output_name).name,
-                            'output name', output_name_str)
+                            "output name", output_name_str)
             check_arg_value(Path(output_name).parent.as_posix(),
-                            'path in output name', output_path_str)
+                            "path in output name", output_path_str)
 
-    with logger.log_task('Retrieve sender and recipient GnuPG keys'):
+    with logger.log_task("Retrieve sender and recipient GnuPG keys"):
         # Retrieve the sender's public and private keys, as well as the
         # recipient's public key. Here is what these keys are needed for:
         #  - sender private key: needed to sign the encrypted data.
@@ -125,11 +124,11 @@ def encrypt(files: List[str],
             validation_keyid=config.key_validation_authority_keyid,
             keyserver_url=config.keyserver_url,
             with_refresh_keys=not offline)
-        logger.info('found the following keys:\n%s\n%s',
-                    f'sender key: {sender_pub_key.uids[0]}, '
-                    f'key ID: {sender_pub_key.key_id}',
-                    '\n'.join([f'recipient key: {key.uids[0]}, '
-                               f'key ID: {key.key_id}'
+        logger.info("found the following keys:\n%s\n%s",
+                    f"sender key: {sender_pub_key.uids[0]}, "
+                    f"key ID: {sender_pub_key.key_id}",
+                    '\n'.join([f"recipient key: {key.uids[0]}, "
+                               f"key ID: {key.key_id}"
                                for key in recipients_pub_key]))
 
         if dtr_id is not None:
@@ -138,66 +137,62 @@ def encrypt(files: List[str],
             if not offline:
                 try:
                     project_id = verify_transfer(
-                        metadata=MetaData(transfer_id=dtr_id,
-                                          sender=HexStr1024(
-                                              sender_pub_key.fingerprint),
-                                          recipients=[HexStr1024(key.fingerprint)
-                                                      for key in recipients_pub_key],
-                                          checksum=HexStr256("0"*64),
-                                          purpose=purpose),
+                        metadata=MetaData(
+                            transfer_id=dtr_id,
+                            sender=HexStr1024(sender_pub_key.fingerprint),
+                            recipients=[HexStr1024(key.fingerprint)
+                                        for key in recipients_pub_key],
+                            checksum=HexStr256("0"*64),
+                            purpose=purpose),
                         filename="missing",
                         portal_endpoint_url=config.dcc_portal_dpkg_endpoint_url)
                     logger.info("DTR ID '%s' is valid for project '%s'",
                                 dtr_id, project_id)
                 except RuntimeError as e:
-                    raise UserError(format(e))
+                    raise UserError(format(e)) from e
     if dry_run:
-        logger.info('dry run completed successfully.')
+        logger.info("dry run completed successfully.")
         return
 
     # Check if gpg key password is correct
     if config.sign_encrypted_data:
-        check_password(sender_pub_key.fingerprint, enforce_passphrase(passphrase),
+        check_password(sender_pub_key.fingerprint,
+                       enforce_passphrase(passphrase),
                        config.gpg_store)
 
     archive_paths = [os.path.join(
         CONTENT_FOLDER,
         os.path.relpath(f, start=root_dir)) for f in files_to_encrypt]
 
-    with logger.log_task('Compute sha256 checksum on input files'):
+    with logger.log_task("Compute sha256 checksum on input files"):
         # Write input file checksums to a file that will be added to the
         # encrypted .tar.gz archive. This information must be encrypted as
         # file names sometimes contain information about their content.
         with subprogress(progress,
                          step_completion_increase=0.2) as scaled_progress:
             checksums = write_checksums(
-                zip(
-                    archive_paths,
-                    progress_file_iter(
-                        files=files_to_encrypt,
-                        mode='rb',
-                        progress=scaled_progress))
-            )
+                zip(archive_paths,
+                    progress_file_iter(files=files_to_encrypt,
+                                       mode='rb',
+                                       progress=scaled_progress)))
 
-    with logger.log_task('Compress input data [this may take a while]'):
+    with logger.log_task("Compress input data [this may take a while]"):
         # Create a new tar.gz file and add all input files to it.
         tarball_file = os.path.join(config.temp_dir, DATA_ARCHIVE)
-        archives: Tuple[ArchiveFileBase, ...] = ((ArchiveInMemoryFile(CHECKSUM_FILE, checksums),) +
-                                                 tuple(ArchiveFile(a_path, f)
-                                                       for a_path, f in zip(
-                                                     archive_paths, progress_file_iter(
-                                                       files=files_to_encrypt,
-                                                       mode='rb',
-                                                       progress=scaled_progress))
-                                                       ))
+        archives: Tuple[ArchiveFileBase, ...] = \
+            ((ArchiveInMemoryFile(CHECKSUM_FILE, checksums),) +
+             tuple(ArchiveFile(a_path, f) for a_path, f in zip(
+                archive_paths, progress_file_iter(files=files_to_encrypt,
+                                                  mode='rb',
+                                                  progress=scaled_progress)))
+            )
         with subprogress(progress,
                          step_completion_increase=0.6) as scaled_progress:
-            write_tar(
-                archives,
-                output_file=tarball_file,
-                mode="w:gz" if compress else "w")
+            write_tar(archives,
+                      output_file=tarball_file,
+                      mode="w:gz" if compress else "w")
 
-    with logger.log_task('Encrypt input data'):
+    with logger.log_task("Encrypt input data"):
         # Encryption is done with the recipient's public key and the optional
         # signing with the user's (i.e sender) private key. The user's private
         # key passphrase is needed to sign the encrypted file.
@@ -215,8 +210,8 @@ def encrypt(files: List[str],
                                             for key in recipients_pub_key],
                     signature_fingerprint=sender_pub_key.fingerprint if
                     config.sign_encrypted_data else None,
-                    passphrase=enforce_passphrase(passphrase) if config.sign_encrypted_data
-                    else None,
+                    passphrase=enforce_passphrase(passphrase) if
+                    config.sign_encrypted_data else None,
                     always_trust=config.always_trust_recipient_key)
         finally:
             # Delete the non-encrypted tarball file. It's no longer needed at
@@ -224,8 +219,8 @@ def encrypt(files: List[str],
             delete_files(tarball_file)
 
     try:
-        with logger.log_task('Compute checksum of encrypted file'):
-            # Compute sha256 sum on encrypted file, so intermediate data integrity
+        with logger.log_task("Compute checksum of encrypted file"):
+            # Compute sha256 sum on encrypted file, so intermediate integrity
             # checks can be carried-out without having to decrypt the data.
             with subprogress(progress,
                              step_completion_increase=0.05) as scaled_progress:
@@ -233,10 +228,11 @@ def encrypt(files: List[str],
                     encrypted_checksum = compute_checksum_sha256(
                         with_progress(f=f, progress=scaled_progress))
 
-        with logger.log_task('Generate metadata file'):
-            # Create a dictionary with all the info we want to store in the .json
-            # file, then pass this dictionary to json.dump that will convert it to
-            # a json file. Use indent=4 to make the output file easier on the eye.
+        with logger.log_task("Generate metadata file"):
+            # Create a dictionary with all the info we want to store in the
+            # .json file, then pass this dictionary to json.dump that will
+            # convert it to a json file.
+            # Use indent=4 to make the output file easier on the eye.
             metadata = MetaData(transfer_id=dtr_id,
                                 sender=HexStr1024(sender_pub_key.fingerprint),
                                 recipients=[HexStr1024(key.fingerprint)
@@ -249,12 +245,15 @@ def encrypt(files: List[str],
             metadata_signature_bytes = b""
             if config.sign_encrypted_data:
                 metadata_signature_bytes = detach_sign_file(
-                    metadata_bytes, sender_pub_key.fingerprint, enforce_passphrase(passphrase),
+                    metadata_bytes,
+                    sender_pub_key.fingerprint,
+                    enforce_passphrase(passphrase),
                     config.gpg_store)
 
-        with logger.log_task('Generate final tarball'):
-            # The default value for the output name is based on date and time when
-            # the script is being run. Example output name is "20191011T145012".
+        with logger.log_task("Generate final tarball"):
+            # The default value for the output name is based on date and time
+            # when the script is being run.
+            # Example output name is "20191011T145012".
             output_name = form_output_tar_name(
                 output_name or metadata.timestamp.strftime(DATE_FMT_FILENAME))  # pylint: disable=no-member
             in_memory_files = ((METADATA_FILE, metadata_bytes),
@@ -266,19 +265,15 @@ def encrypt(files: List[str],
                           for path, content in in_memory_files) +
                     tuple(ArchiveFile(os.path.relpath(f.name, start=config.temp_dir), f)
                           for f in progress_file_iter(
-                        files=[
-                            encrypted_file],
-                        mode='rb',
-                        progress=scaled_progress)
-                    ))
-                write_tar(
-                    archives,
-                    output_file=output_name,
-                    mode="w")
+                            files=[encrypted_file],
+                            mode='rb',
+                            progress=scaled_progress))
+                    )
+                write_tar(archives, output_file=output_name, mode='w')
     finally:
         delete_files(encrypted_file)
 
-    logger.info('Completed data encryption: %s', output_name)
+    logger.info("Completed data encryption: %s", output_name)
 
 def enforce_passphrase(passphrase: Optional[str]) -> str:
     if passphrase is None:
