@@ -7,7 +7,8 @@ from ..utils.log import create_logger
 from ..utils.progress import ProgressInterface
 from ..core.crypt import get_recipient_email, extract_pub_key_ids, \
     validated_keys_by_ids, gpg
-from ..core.archive import check_tar, extract, METADATA_FILE, DATA_FILE_ENCRYPTED
+from ..core.archive import check_tar, extract, METADATA_FILE, \
+    DATA_FILE_ENCRYPTED
 from ..core.metadata import load_metadata, verify_transfer
 from ..core.error import UserError
 from ..protocols import needs_argument
@@ -24,8 +25,9 @@ def transfer(files: List[str],
              protocol_args: dict,
              config: Config,
              dry_run: bool = False,
+             verify: bool = True,
              progress: ProgressInterface = None):
-    """ Transfer file to the selected recipient on the BiomedIT network.
+    """ Transfer file(s) to the selected recipient on the BiomedIT network.
     """
 
     logger.info("""Input summary:
@@ -50,13 +52,19 @@ def transfer(files: List[str],
                     config.key_validation_authority_keyid,
                     config.keyserver_url))
             metadata = load_metadata(metadata)
-            try:
-                project_id = verify_transfer(metadata=metadata, filename=tar,
-                    portal_endpoint_url=config.dcc_portal_dpkg_endpoint_url)
-                logger.info("Transfer '%s' is a valid for project '%s'",
-                            metadata.transfer_id, project_id)
-            except RuntimeError as e:
-                raise UserError(format(e))
+            if verify:
+                if metadata.transfer_id is None:
+                    raise UserError("DTR (Data Transfer Request) ID is "
+                                    "missing in file metadata.")
+                try:
+                    project_id = verify_transfer(
+                        metadata=metadata,
+                        filename=tar,
+                        portal_endpoint_url=config.dcc_portal_dpkg_endpoint_url)
+                    logger.info("DTR ID '%s' is valid for project '%s'",
+                                metadata.transfer_id, project_id)
+                except RuntimeError as e:
+                    raise UserError(format(e)) from e
             files_by_recipient.setdefault(keys, []).append(tar)
 
     if dry_run:
